from geojson.codec import dump, dumps, load, loads, GeoJSONEncoder
from geojson.utils import coords, map_coords
from geojson.geometry import Point, LineString, Polygon
from geojson.geometry import MultiLineString, MultiPoint, MultiPolygon
from geojson.geometry import GeometryCollection
from geojson.feature import Feature, FeatureCollection
from geojson.base import GeoJSON
from geojson._version import __version__, __version_info__

__all__ = (
        ["dump", "dumps", "load", "loads", "GeoJSONEncoder"] +
        ["coords", "map_coords"] +
        ["Point", "LineString", "Polygon"] +
        ["MultiLineString", "MultiPoint", "MultiPolygon"] +
        ["GeometryCollection"] +
        ["Feature", "FeatureCollection"] +
        ["GeoJSON"] +
        ["__version__", "__version_info__"]
)



from geojson.geometry import Point, LineString, Polygon
from geojson.geometry import MultiLineString, MultiPoint, MultiPolygon
from geojson.geometry import GeometryCollection
from geojson.feature import Feature, FeatureCollection
from geojson.base import GeoJSON

__all__ = (
        ["Point", "LineString", "Polygon"] +
        ["MultiLineString", "MultiPoint", "MultiPolygon"] +
        ["GeometryCollection"] +
        ["Feature", "FeatureCollection"] +
        ["GeoJSON"]
)



import unittest

import geojson


class FeatureCollectionsTest(unittest.TestCase):
    def test_to_instance_converts_nested_features(self):
        """to_instance() should convert dict features to Feature objects in FeatureCollection."""

        feature_collection_dict = {
            "type": "FeatureCollection",
            "features": [
                {
                    "type": "Feature",
                    "properties": {"foo": "bar"},
                    "geometry": {
                        "type": "Polygon",
                        "coordinates": [[[0, 0], [0, 1], [1, 1], [1, 0], [0, 0]]],
                    },
                },
            ],
        }

        obj = geojson.GeoJSON.to_instance(feature_collection_dict)
        self.assertTrue(isinstance(obj, geojson.FeatureCollection))
        self.assertTrue(isinstance(obj.features[0], geojson.Feature))
        self.assertTrue(obj.is_valid)
